from Fortuna import *


def zero_cool_test(n):
    distribution_timer(random_index, n)

    distribution_timer(front_linear, n)
    distribution_timer(middle_linear, n)
    distribution_timer(back_linear, n)
    distribution_timer(quantum_linear, n)

    distribution_timer(front_gauss, n)
    distribution_timer(middle_gauss, n)
    distribution_timer(back_gauss, n)
    distribution_timer(quantum_gauss, n)

    distribution_timer(front_poisson, n)
    distribution_timer(middle_poisson, n)
    distribution_timer(back_poisson, n)
    distribution_timer(quantum_poisson, n)

    distribution_timer(quantum_monty, n)


if __name__ == "__main__":
    zero_cool_test(10)
    zero_cool_test(-10)



from Fortuna import *


def monty_tests():
    some_collection = (i for i in range(10))
    print("\nQuantum Monty Methods:\n")
    monty = QuantumMonty(some_collection)

    distribution_timer(monty.flat_uniform)
    distribution_timer(monty.front_linear)
    distribution_timer(monty.middle_linear)
    distribution_timer(monty.back_linear)
    distribution_timer(monty.quantum_linear)
    distribution_timer(monty.front_gauss)
    distribution_timer(monty.middle_gauss)
    distribution_timer(monty.back_gauss)
    distribution_timer(monty.quantum_gauss)
    distribution_timer(monty.front_poisson)
    distribution_timer(monty.middle_poisson)
    distribution_timer(monty.back_poisson)
    distribution_timer(monty.quantum_poisson)
    distribution_timer(monty.quantum_monty)


if __name__ == "__main__":
    monty_tests()



from Fortuna import *


print("\nWeighted Tables:\n")
population = ("A", "B", "C", "D")

cum_weights = (1, 3, 6, 10)
rel_weights = (1, 2, 3, 4)

cum_weighted_table = zip(cum_weights, population)
rel_weighted_table = zip(rel_weights, population)


cum_weighted_choice = CumulativeWeightedChoice(cum_weighted_table)
distribution_timer(cum_weighted_choice)

rel_weighted_choice = RelativeWeightedChoice(rel_weighted_table)
distribution_timer(rel_weighted_choice)



from Fortuna import *


def flex_cat_tests():
    print("\nFlexCat Test Suite\n")

    some_matrix = {
        "A": (1, 2, 3),
        "B": (10, 20, 30),
        "C": (100, 200, 300),
    }

    str_zero_cool_dispatch = (
        "front_linear", "middle_linear", "back_linear", "quantum_linear",
        "front_gauss", "middle_gauss", "back_gauss", "quantum_gauss",
        "front_poisson", "middle_poisson", "back_poisson", "quantum_poisson",
        "quantum_monty", "flat_uniform",
    )

    for v_bias in str_zero_cool_dispatch:
        for k_bias in str_zero_cool_dispatch:
            f_cat = FlexCat(some_matrix, key_bias=k_bias, val_bias=v_bias)
            distribution_timer(f_cat, num_cycles=1000)


if __name__ == "__main__":
    flex_cat_tests()
